@@ -353,6 +353,25 @@ try {
             echo json_encode($result);
             exit;
             
+        case 'get_wordpress_versions':
+            // Fetch WordPress versions for all sites dynamically
+            $siteIds = $_POST['site_ids'] ?? [];
+            $versions = [];
+            
+            foreach ($siteIds as $siteId) {
+                $site = $wpManager->getSite($siteId);
+                if ($site) {
+                    $containerName = $site['container_name'];
+                    $user = $site['user'];
+                    $version = $wpManager->getWordPressVersion($containerName, $user);
+                    $versions[$siteId] = $version ?: 'Unknown';
+                }
+            }
+            
+            ob_clean();
+            echo json_encode(['success' => true, 'versions' => $versions]);
+            exit;
+            
         default:
             throw new Exception('Invalid action');
     }
