@@ -133,7 +133,7 @@ if (!array_key_exists($page, $allowed_pages)) {
           <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
         <![endif]-->
     </head>
-    <body class="fixed-navbar fixed-sidebar">
+    <body class="fixed-navbar fixed-sidebar<?php echo (isset($_SESSION['large_fonts']) && $_SESSION['large_fonts']) ? ' large-fonts' : ''; ?>">
         <!-- Static navbar -->
         <!-- Simple splash screen-->
         <div class="splash"><div class="splash-title"><div class="spinner">
@@ -157,6 +157,14 @@ if (!array_key_exists($page, $allowed_pages)) {
                 
                 <!-- User Dropdown -->
                 <div class="navbar-nav ms-auto">
+                    <!-- Font Size Toggle -->
+                    <button class="font-size-toggle me-3<?php echo (isset($_SESSION['large_fonts']) && $_SESSION['large_fonts']) ? ' active' : ''; ?>" 
+                            id="fontSizeToggle" 
+                            title="Toggle larger fonts">
+                        <i class="fa fa-font"></i>
+                        <span class="d-none d-sm-inline">Aa</span>
+                    </button>
+                    
                     <span class="navbar-text text-light me-3">
                         Welcome, <?php 
                         if ($is_delegated_user && !empty($delegated_display_name)) {
@@ -374,5 +382,35 @@ if (!array_key_exists($page, $allowed_pages)) {
         <script src="js/morris_chart/morris.js"></script>
         
         <?php include 'includes/password-modal.php'; ?>
+        
+        <!-- Font Size Toggle Script -->
+        <script>
+        document.addEventListener('DOMContentLoaded', function() {
+            const fontToggle = document.getElementById('fontSizeToggle');
+            if (fontToggle) {
+                fontToggle.addEventListener('click', function() {
+                    // Send AJAX request to toggle font size
+                    fetch('api/font-size-toggle.php', {
+                        method: 'POST',
+                        headers: {
+                            'Content-Type': 'application/x-www-form-urlencoded',
+                            'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
+                        },
+                        body: 'action=toggle'
+                    })
+                    .then(response => response.json())
+                    .then(data => {
+                        if (data.success) {
+                            // Toggle the class on body
+                            document.body.classList.toggle('large-fonts', data.large_fonts);
+                            // Toggle active state on button
+                            fontToggle.classList.toggle('active', data.large_fonts);
+                        }
+                    })
+                    .catch(error => console.error('Error toggling font size:', error));
+                });
+            }
+        });
+        </script>
     </body>
 </html>
\ No newline at end of file
