@@ -311,7 +311,7 @@ class security_manager {
     }
     
     public function get_blocked_ips() {
-        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE unblock_time > :time ORDER BY block_time DESC');
+        $stmt = $this->db->prepare('SELECT * FROM blocked_ips WHERE unblock_time > :time OR unblock_time = 0 ORDER BY block_time DESC');
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         
@@ -394,8 +394,8 @@ class security_manager {
     }
     
     public function get_security_stats() {
-        // Get current blocked IPs count
-        $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM blocked_ips WHERE unblock_time > :time');
+        // Get current blocked IPs count (including indefinite blocks)
+        $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM blocked_ips WHERE unblock_time > :time OR unblock_time = 0');
         $stmt->bindValue(':time', time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
         $blocked_count = $result->fetchArray(SQLITE3_ASSOC)['count'];
