@@ -652,7 +652,7 @@ SSLCryptoDevice builtin
 <IfModule mod_tls.c>
     TLSEngine on
     TLSRequired on
-    TLSRSACertificateFile {$pem_path}
+    TLSECCertificateFile {$pem_path}
     TLSVerifyClient off
     TLSLog /var/log/proftpd/tls.log
     TLSProtocol TLSv1.2 TLSv1.3
